<?php 
require_once('stripe\stripe-php\init.php');
require('duda_API.php');

//Working
$payload = @file_get_contents("php://input");
$data = json_decode($payload);

$token = $data->token;
$account_name = $data->account_name;
$site_name = $data->site_name;
$first_name = $data->first_name;
$last_name = $data->last_name;
$email =  $data->email;
$plan_id = $data->plan_id;

$currency = 'usd';

//Main Settings for Create Account
$create_account_setting = array(
    "id" =>  $site_name,
    "source" => $token, // obtained with Stripe.js
    "email" => $account_name,
    "description" => 'DIY - '.$plan_id,
    "metadata" => [
        "ACCOUNT DETAILS" => '#################################',
        "Account Name" => $account_name,
        "Email Address" => $account_name,
        "Site Name" => $site_name,
        "STRIPE DETAILS" => '#################################',
        "Stripe First Name" => $first_name,
        "Stripe Last Name" => $last_name,
        "Stripe Email" => $email,
    ]    
);

/*
DEFAULTS PROCESS
Create Customer -> Create Charge or Create Subscription -> Publish Site 
*/
//Working..
$customerID = create_customer($create_account_setting);//cus_FLbWyJSrrtJwTS

//Main Settings for Create Subscription
$subscription_settings = array(
    "customer" => $customerID,
    "items" => [ ["plan" => $plan_id] ]
);

// Check if coupon is set
if(isset($data->couponID)){
    $subscription_settings['coupon'] = $data->couponID;
}

$subscription_Status = create_subscription($subscription_settings);//active || trialing
//$charge_Status = create_charge($customerID);//succeeded

if($subscription_Status == 'active' || $subscription_Status == 'trialing'){
    
    $publish_Status = publish_Site($site_name);//204
    if($publish_Status['response_code'] == 204){
        $retArr = [
            "status" => true,
            "account_name" => $GLOBALS['account_name'],
            "first_name" => $GLOBALS['first_name'],
            "last_name" => $GLOBALS['last_name'],
            "site_name" => $GLOBALS['site_name'],
            "plan_id" => $GLOBALS['account_name'],
            "currency" => $GLOBALS['currency']
        ];

        //PERMISSION AFTER PUBLISH UPDATE
        $permission_after_publish = '{"permissions":["PUSH_NOTIFICATIONS","REPUBLISH","EDIT","INSITE","CUSTOM_DOMAIN","RESET","E_COMMERCE","SEO","STATS_TAB","DEV_MODE","BACKUPS","BLOG","CONTENT_LIBRARY"]}';
        grant_Access($GLOBALS['account_name'],$GLOBALS['first_name'],$permission_after_publish);

        print_r(json_encode($retArr));
    }else{
        stripe_Error_Handler([
            'request'=>'Publishing Site',
            'code'=>$publish_Status['response_code'],
            'message'=>$publish_Status['message'],
            'account_name'=>$GLOBALS['account_name'],
            'first_name'=>$GLOBALS['first_name']
        ]);
    }

}

//Create Customer
function create_customer($create_account_setting){
    try{

        \Stripe\Stripe::setApiKey(SK_KEY);
        $customer = \Stripe\Customer::create($create_account_setting);
        return $customer->id;

    }catch(Exception $e){

        stripe_Error_Handler([
            'request'=>'Create Customer',
            'code'=>'CreatingCustomerFailed',
            'message'=>$e->getMessage(),
            'account_name'=>$GLOBALS['account_name'],
            'first_name'=>$GLOBALS['first_name']
        ]);
        exit;
    }
}

function create_subscription($subscription_settings){
    try{
        \Stripe\Stripe::setApiKey(SK_KEY);
        $subscription = \Stripe\Subscription::create($subscription_settings);
        return $subscription->status;//active || trialing
    } catch(Exception $e){
        stripe_Error_Handler([
            'request'=>'Create Subscription',
            'code'=>'CreatingSubscriptionFailed',
            'message'=>$e->getMessage(),
            'account_name'=>$GLOBALS['account_name'],
            'first_name'=>$GLOBALS['first_name']
        ]);
        exit;
    }
}

//Create Charge
function create_charge($customerID){
    try{
        \Stripe\Stripe::setApiKey(SK_KEY);
        // $date = date("Y-m-d", strtotime("+1 month"));
        $charge = \Stripe\Charge::create(array(
          "amount" => 100,
          "currency" => $GLOBALS['currency'] ,
          "description" => 'DIY',
          "customer" => $customerID,
          "receipt_email" => $GLOBALS['account_name']      
        ));
        return $charge->status;//succeeded
    }catch(Exception $e){
        stripe_Error_Handler([
            'request'=>'Create Charge',
            'code'=>'CreatingChargeFailed',
            'message'=>$e->getMessage(),
            'account_name'=>$GLOBALS['account_name'],
            'first_name'=>$GLOBALS['first_name']
        ]);
        exit;
    }    
    
}

function stripe_Error_Handler($resp_arr){
    print_r(json_encode($resp_arr));
}

?>